#
# spec file for package suil
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _description \
Suil is a lightweight C library for loading and wrapping LV2 plugin UIs.\
\
Suil makes it possible to load a UI of any toolkit in a host using any\
other toolkit (assuming the toolkits are both supported by Suil).\
Hosts do not need to build against or link to foreign toolkit libraries\
to use UIs written with that toolkit (Suil performs its magic at\
runtime using dynamically loaded modules). The API is designed such that\
hosts do not need to explicitly support particular toolkits whatsoever.\
If Suil supports a particular toolkit, then all hosts that use Suil will\
support that toolkit.

Name:           suil
Version:        0.10.0
Release:        2.1
Summary:        Lightweight C library for loading and wrapping LV2 plugin UIs
License:        ISC
Group:          Development/Libraries/C and C++
Url:            https://drobilla.net/software/suil/
Source:         https://download.drobilla.net/suil-%{version}.tar.bz2
BuildRequires:  gcc-c++
BuildRequires:  gtk2-devel
BuildRequires:  gtk3-devel >= 3.14.0
BuildRequires:  lv2-devel
BuildRequires:  pkgconfig
BuildRequires:  python
BuildRequires:  python-rdflib
BuildRequires:  pkgconfig(Qt5Widgets) >= 5.1.0

%description
%{_description}

%package     -n libsuil-0-0
Summary:        Lightweight C library for loading and wrapping LV2 plugin UIs
Group:          System/Libraries

%description -n libsuil-0-0
%{_description}

%package        devel
Summary:        Development files for the suil library
Group:          Development/Libraries/C and C++
Requires:       libsuil-0-0 == %{version}
Requires:       pkgconfig

%description    devel
Development files needed to build applications against suil library.

%package     -n suil-plugin-gtk2-in-qt5
Summary:        Shared object for GTK2 hosts displaying Qt5 LV2 GUIs
Group:          System/Libraries
Requires:       gtk2-tools
Requires:       libsuil-0-0 == %{version}
Supplements:    packageand(gtk2:lv2)

%description -n suil-plugin-gtk2-in-qt5
Module plugin for:
* GTK2 hosts displaying Qt5 LV2 GUIs using suil

%package     -n suil-plugin-qt5-in-gtk2
Summary:        Shared object for Qt5 hosts displaying GTK2 LV2 GUIs
Group:          System/Libraries
Requires:       libsuil-0-0 == %{version}
Requires:       python-qt5
Supplements:    packageand(libQt5Widgets5:lv2)

%description -n suil-plugin-qt5-in-gtk2
Module plugin for:
* Qt5 hosts displaying GTK2 LV2 GUIs using suil

%package     -n suil-plugin-x11
Summary:        Shared object for X11 LV2 GUIs
Group:          System/Libraries
Requires:       libsuil-0-0 == %{version}
Supplements:    packageand(libX116:lv2)

%description -n suil-plugin-x11
Module plugin for:
* X11 LV2 GUIs using suil

%package     -n suil-plugin-x11-in-gtk2
Summary:        Shared object for GTK2 hosts displaying X11 LV2 GUIs
Group:          System/Libraries
Requires:       gtk2-tools
Requires:       libsuil-0-0 == %{version}
Obsoletes:      libsuil-x11-in-gtk2 < %{version}
Provides:       libsuil-x11-in-gtk2 = %{version}
Supplements:    packageand(gtk2:lv2)

%description -n suil-plugin-x11-in-gtk2
Module plugin for:
* GTK2 hosts displaying X11 LV2 GUIs using suil

%package     -n suil-plugin-x11-in-gtk3
Summary:        Shared object for GTK3 hosts displaying X11 LV2 GUIs
Group:          System/Libraries
Requires:       gtk3-tools
Requires:       libsuil-0-0 == %{version}
Supplements:    packageand(gtk3:lv2)

%description -n suil-plugin-x11-in-gtk3
Module plugin for:
* GTK3 hosts displaying X11 LV2 GUIs using suil

%package     -n suil-plugin-x11-in-qt5
Summary:        Shared object for Qt5 hosts displaying X11 LV2 GUIs
Group:          System/Libraries
Requires:       libsuil-0-0 == %{version}
Requires:       python-qt5
Supplements:    packageand(libQt5Widgets5:lv2)

%description -n suil-plugin-x11-in-qt5
Module plugin for:
* Qt5 hosts displaying x11 LV2 GUIs using suil

%prep
%setup -q

%build
./waf configure --prefix=%{_prefix} --libdir=%{_libdir}
./waf

%install
./waf install --destdir=%{buildroot}

%post -n libsuil-0-0 -p /sbin/ldconfig

%postun -n libsuil-0-0 -p /sbin/ldconfig

%files devel
%defattr(-,root,root,-)
%dir %{_includedir}/suil-0/
%dir %{_includedir}/suil-0/suil
%{_libdir}/libsuil-0.so
%{_includedir}/suil-0/suil/*.h
%{_libdir}/pkgconfig/suil-0.pc

%files -n libsuil-0-0
%defattr(-,root,root,-)
%doc COPYING README
%dir %{_libdir}/suil-0
%{_libdir}/libsuil-0.so.*

%files -n suil-plugin-gtk2-in-qt5
%defattr(-,root,root,-)
%doc COPYING README
%{_libdir}/suil-0/libsuil_gtk2_in_qt5.so

%files -n suil-plugin-qt5-in-gtk2
%defattr(-,root,root,-)
%doc COPYING README
%{_libdir}/suil-0/libsuil_qt5_in_gtk2.so

%files -n suil-plugin-x11
%defattr(-,root,root,-)
%doc COPYING README
%{_libdir}/suil-0/libsuil_x11.so

%files -n suil-plugin-x11-in-gtk2
%defattr(-,root,root,-)
%doc COPYING README
%{_libdir}/suil-0/libsuil_x11_in_gtk2.so

%files -n suil-plugin-x11-in-gtk3
%defattr(-,root,root,-)
%doc COPYING README
%{_libdir}/suil-0/libsuil_x11_in_gtk3.so

%files -n suil-plugin-x11-in-qt5
%defattr(-,root,root,-)
%doc COPYING README
%{_libdir}/suil-0/libsuil_x11_in_qt5.so

%changelog
* Sun Feb 18 2018 jengelh@inai.de
- Fix SRPM group.
* Thu Feb 15 2018 aloisio@gmx.com
- Fixed supplements lines
* Wed Feb 14 2018 aloisio@gmx.com
- Update to version 0.10.0
  * Add support for X11 in Gtk3
  * Add support for Qt5 in Gtk2
  * Add suil_init() to support early initialization and passing
    any necessary information that may be needed in the future
    (thanks Stefan Westerfeld)
  * Fix minor memory errors
  * Fix building with X11 against custom LV2 install path (thanks
    Robin Gareus)
  version 0.8.4
  * Configure based on compiler target OS for cross-compilation
  * Add Cocoa in Gtk wrapper (patch from Robin Gareus)
  * Various Windows fixes (patches from Robin Gareus)
  * Center X11 UIs in Gtk (patch from Robin Gareus)
  * Fix initial size of resizable X11 UIs in Gtk (patch from
    Robin Gareus)
  * Bubble X11 key events up to Gtk parent (patch from Filipe
    Coelho)
  * Add Gtk2 and X11 in Qt5 wrappers (patch from Rui Nuno Capela)
  * Fix compilation with -Wl,--no-undefined
  * Fix a few minor/unlikely memory errors
  * Gracefully handle failure to open wrapper
  * Only report suil_ui_supported() if necessary wrapper is
    compiled in
  * Upgrade to waf 1.8.14
- Dropped qt4 plugins
- Split plugins into separate packages so that only actually
  required libraries are pulled in
* Sat Dec 12 2015 davejplater@gmail.com
- Packaged plugin modules in plugins package
* Sat Aug  9 2014 Rui Nuno Capela <rncbc@rncbc.org> - 0.8.2-10
- New upstream release.
  suil (0.8.2) stable;
  * Fix embedding several Qt UIs in Gtk
  * Add configure options to disable all Gtk or Qt support
  * Upgrade to waf 1.7.16
* Sun Jan  5 2014 Rui Nuno Capela <rncbc@rncbc.org> - 0.8.0-9
- New upstream release.
  suil (0.8.0) stable;
  * Add suil_instance_get_handle (patch from Rui Nuno Capela)
  * Fix compilation errors on some systems
  * Upgrade to waf 1.7.14
  suil (0.6.16) stable;
  * Fix suil_instance_extension_data() for UIs with NULL extension_data
  * Fix crashes and resizing for X11 in Qt (patch from Rui Nuno Capela)
  suil (0.6.14) stable;
  * Print system error message if module fails to load
  * Lower dependency from Gtk 2.24 introduced in 0.6.12
  * Add support for new LV2 idle interface
  * Support resizing for X11 in Gtk (patch from Robin Gareus)
  * Upgrade to waf 1.7.11
  suil (0.6.12) stable;
  * Fix key events for X11 in Gtk without using a troublesome event filter
  * Fix crash when a broken UI returns a NULL descriptor
  * Fix compilation on BSD
  suil (0.6.10) stable;
  * Downgrade to waf 1.7.5, previous version does not build modules due to
    package check breakage in waf 1.7.6
  suil (0.6.8) stable;
  * Fix crash in x11_in_gtk2 when event_filter fires before widget is realized
  * Use libgtk-x11-2.0.so.0 (with .0 suffix) by default which is available on
    systems without the dev package
  * Update to waf 1.7.8 and autowaf r90 (install docs to versioned directory)
  suil (0.6.6) stable;
  * Fix embedding Gtk in Qt as a child widget (support reparenting)
  * Support for wrapping native Windows UIs in Gtk2
  * Gracefully handle UIs with no port_event method
  * Replace host provided features that match Suil implemented features, rather
    than passing UIs duplicate features
  * Disable timestamps in HTML documentation for reproducible build
  suil (0.6.4) stable;
  * Correctly handle resizing for Gtk2 in Qt4
  * Improve documentation
  suil (0.6.2) stable;
  * Fix crashes when wrapper widget is destroyed by toolkit before
    suil cleanup function is called
  * Link Gtk wrappers with 'nodelete' to avoid Glib type errors
  * Allow run-time configuration of module directory via environment variable
    SUIL_MODULE_DIR
  suil (0.6.0) stable;
  * Use path variables in pkgconfig files
  * Add support for embedding X11 UIs (ui:X11UI)
  * Support new LV2 UI features automatically if provided by host
  suil (0.4.4) stable;
  * Fix embedding Gtk2 Qt4 UIs in Qt4 hosts that do not link to Gtk2
  suil (0.4.2) stable;
  * Fix compilation issues on some systems
  * Fix build system Python 3 compatibility
  suil (0.4.0) stable;
  * Initial release
